@@ -25,44 +25,39 @@ class CreateBackupRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'CreateBackup','rds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_BackupStrategy(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_BackupStrategy(self): # String
 		return self.get_query_params().get('BackupStrategy')
 
-	def set_BackupStrategy(self,BackupStrategy):
-		self.add_query_param('BackupStrategy',BackupStrategy)
-
-	def get_DBInstanceId(self):
+	def set_BackupStrategy(self, BackupStrategy):  # String
+		self.add_query_param('BackupStrategy', BackupStrategy)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_BackupType(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_BackupType(self): # String
 		return self.get_query_params().get('BackupType')
 
-	def set_BackupType(self,BackupType):
-		self.add_query_param('BackupType',BackupType)
-
-	def get_BackupMethod(self):
+	def set_BackupType(self, BackupType):  # String
+		self.add_query_param('BackupType', BackupType)
+	def get_BackupMethod(self): # String
 		return self.get_query_params().get('BackupMethod')
 
-	def set_BackupMethod(self,BackupMethod):
-		self.add_query_param('BackupMethod',BackupMethod)
-
-	def get_DBName(self):
+	def set_BackupMethod(self, BackupMethod):  # String
+		self.add_query_param('BackupMethod', BackupMethod)
+	def get_DBName(self): # String
 		return self.get_query_params().get('DBName')
 
-	def set_DBName(self,DBName):
-		self.add_query_param('DBName',DBName)
\ No newline at end of file
+	def set_DBName(self, DBName):  # String
+		self.add_query_param('DBName', DBName)
