@@ -25,38 +25,34 @@ class DescribeDedicatedHostGroupsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DescribeDedicatedHostGroups','rds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_ImageCategory(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_ImageCategory(self): # String
 		return self.get_query_params().get('ImageCategory')
 
-	def set_ImageCategory(self,ImageCategory):
-		self.add_query_param('ImageCategory',ImageCategory)
-
-	def get_DedicatedHostGroupId(self):
+	def set_ImageCategory(self, ImageCategory):  # String
+		self.add_query_param('ImageCategory', ImageCategory)
+	def get_DedicatedHostGroupId(self): # String
 		return self.get_query_params().get('DedicatedHostGroupId')
 
-	def set_DedicatedHostGroupId(self,DedicatedHostGroupId):
-		self.add_query_param('DedicatedHostGroupId',DedicatedHostGroupId)
\ No newline at end of file
+	def set_DedicatedHostGroupId(self, DedicatedHostGroupId):  # String
+		self.add_query_param('DedicatedHostGroupId', DedicatedHostGroupId)
