@@ -25,56 +25,49 @@ class ModifyDBProxyInstanceRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ModifyDBProxyInstance','rds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_EffectiveTime(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_EffectiveTime(self): # String
 		return self.get_query_params().get('EffectiveTime')
 
-	def set_EffectiveTime(self,EffectiveTime):
-		self.add_query_param('EffectiveTime',EffectiveTime)
-
-	def get_EffectiveSpecificTime(self):
+	def set_EffectiveTime(self, EffectiveTime):  # String
+		self.add_query_param('EffectiveTime', EffectiveTime)
+	def get_EffectiveSpecificTime(self): # String
 		return self.get_query_params().get('EffectiveSpecificTime')
 
-	def set_EffectiveSpecificTime(self,EffectiveSpecificTime):
-		self.add_query_param('EffectiveSpecificTime',EffectiveSpecificTime)
-
-	def get_DBInstanceId(self):
+	def set_EffectiveSpecificTime(self, EffectiveSpecificTime):  # String
+		self.add_query_param('EffectiveSpecificTime', EffectiveSpecificTime)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_DBProxyInstanceNum(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_DBProxyInstanceNum(self): # String
 		return self.get_query_params().get('DBProxyInstanceNum')
 
-	def set_DBProxyInstanceNum(self,DBProxyInstanceNum):
-		self.add_query_param('DBProxyInstanceNum',DBProxyInstanceNum)
-
-	def get_DBProxyInstanceType(self):
+	def set_DBProxyInstanceNum(self, DBProxyInstanceNum):  # String
+		self.add_query_param('DBProxyInstanceNum', DBProxyInstanceNum)
+	def get_DBProxyInstanceType(self): # String
 		return self.get_query_params().get('DBProxyInstanceType')
 
-	def set_DBProxyInstanceType(self,DBProxyInstanceType):
-		self.add_query_param('DBProxyInstanceType',DBProxyInstanceType)
\ No newline at end of file
+	def set_DBProxyInstanceType(self, DBProxyInstanceType):  # String
+		self.add_query_param('DBProxyInstanceType', DBProxyInstanceType)
