@@ -25,62 +25,54 @@ class ModifyDBProxyRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ModifyDBProxy','rds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_DBInstanceId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_DBProxyInstanceNum(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_DBProxyInstanceNum(self): # String
 		return self.get_query_params().get('DBProxyInstanceNum')
 
-	def set_DBProxyInstanceNum(self,DBProxyInstanceNum):
-		self.add_query_param('DBProxyInstanceNum',DBProxyInstanceNum)
-
-	def get_ConfigDBProxyService(self):
+	def set_DBProxyInstanceNum(self, DBProxyInstanceNum):  # String
+		self.add_query_param('DBProxyInstanceNum', DBProxyInstanceNum)
+	def get_ConfigDBProxyService(self): # String
 		return self.get_query_params().get('ConfigDBProxyService')
 
-	def set_ConfigDBProxyService(self,ConfigDBProxyService):
-		self.add_query_param('ConfigDBProxyService',ConfigDBProxyService)
-
-	def get_VSwitchId(self):
+	def set_ConfigDBProxyService(self, ConfigDBProxyService):  # String
+		self.add_query_param('ConfigDBProxyService', ConfigDBProxyService)
+	def get_VSwitchId(self): # String
 		return self.get_query_params().get('VSwitchId')
 
-	def set_VSwitchId(self,VSwitchId):
-		self.add_query_param('VSwitchId',VSwitchId)
-
-	def get_VPCId(self):
+	def set_VSwitchId(self, VSwitchId):  # String
+		self.add_query_param('VSwitchId', VSwitchId)
+	def get_VPCId(self): # String
 		return self.get_query_params().get('VPCId')
 
-	def set_VPCId(self,VPCId):
-		self.add_query_param('VPCId',VPCId)
-
-	def get_InstanceNetworkType(self):
+	def set_VPCId(self, VPCId):  # String
+		self.add_query_param('VPCId', VPCId)
+	def get_InstanceNetworkType(self): # String
 		return self.get_query_params().get('InstanceNetworkType')
 
-	def set_InstanceNetworkType(self,InstanceNetworkType):
-		self.add_query_param('InstanceNetworkType',InstanceNetworkType)
\ No newline at end of file
+	def set_InstanceNetworkType(self, InstanceNetworkType):  # String
+		self.add_query_param('InstanceNetworkType', InstanceNetworkType)
